@@ -17,8 +17,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using Mono.Unix;
-
 using gbrainy.Core.Main;
 
 namespace gbrainy.Games.Logic
@@ -29,24 +27,24 @@ namespace gbrainy.Games.Logic
 		private int type;
 
 		public override string Name {
-			get {return Catalog.GetString ("Squares");}
+			get {return Translations.GetString ("Squares");}
 		}
 
 		public override string Question {
-			get {return Catalog.GetString ("How many squares of any size do you count in the figure below?");} 
+			get {return Translations.GetString ("How many squares of any size do you count in the figure below?");} 
 		}
 
 		public override string Tip {
-			get { return Catalog.GetString ("A square is a rectangle with sides of equal length. A square can also be built from other squares.");}
+			get { return Translations.GetString ("A square is a rectangle with sides of equal length. A square can also be built from other squares.");}
 		}
 
 		public override string Rationale {
 			get {
 				switch (type) {
 				case 0:
-					return Catalog.GetString ("There are 16 single squares, 9 squares made by 4 single squares, 4 squares made by 9 single squares and 1 square made by 16 single squares.");
+					return Translations.GetString ("There are 16 single squares, 9 squares made by 4 single squares, 4 squares made by 9 single squares and 1 square made by 16 single squares.");
 				case 1:
-					return Catalog.GetString ("There are 9 single squares, 4 squares made by 4 single squares and 1 square made by 9 single squares.");
+					return Translations.GetString ("There are 9 single squares, 4 squares made by 4 single squares and 1 square made by 9 single squares.");
 				default:
 					return string.Empty;
 				}
@@ -66,9 +64,9 @@ namespace gbrainy.Games.Logic
 			if (type == 0) {
 				rows++;
 				columns++;
-				right_answer = "30";
+				Answer.Correct = "30";
 			} else {
-				right_answer = "14";
+				Answer.Correct = "14";
 			}
 		}
 
